@@ -9,7 +9,7 @@
 #' @inheritSection mlr_learners_classif.ranger Custom mlr3 defaults
 #'
 #' @templateVar id regr.ranger
-#' @template section_dictionary_learner
+#' @template learner
 #'
 #' @references
 #' `r format_bib("wright_2017", "breiman_2001")`
@@ -25,7 +25,6 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-
       ps = ps(
         alpha                        = p_dbl(default = 0.5, tags = "train"),
         always.split.variables       = p_uty(tags = "train"),
@@ -40,7 +39,7 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
         mtry.ratio                   = p_dbl(lower = 0, upper = 1, tags = "train"),
         num.random.splits            = p_int(1L, default = 1L, tags = "train"),
         num.threads                  = p_int(1L, default = 1L, tags = c("train", "predict", "threads")),
-        num.trees                    = p_int(1L, default = 500L, tags = c("train", "predict")),
+        num.trees                    = p_int(1L, default = 500L, tags = c("train", "predict", "hotstart")),
         oob.error                    = p_lgl(default = TRUE, tags = "train"),
         quantreg                     = p_lgl(default = FALSE, tags = "train"),
         regularization.factor        = p_uty(default = 1, tags = "train"),
@@ -52,7 +51,7 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
         scale.permutation.importance = p_lgl(default = FALSE, tags = "train"),
         se.method                    = p_fct(c("jack", "infjack"), default = "infjack", tags = "predict"), # FIXME: only works if predict_type == "se". How to set dependency?
         seed                         = p_int(default = NULL, special_vals = list(NULL), tags = c("train", "predict")),
-        split.select.weights         = p_dbl(0, 1, tags = "train"),
+        split.select.weights         = p_uty(default = NULL, tags = "train"),
         splitrule                    = p_fct(c("variance", "extratrees", "maxstat"), default = "variance", tags = "train"),
         verbose                      = p_lgl(default = TRUE, tags = c("train", "predict")),
         write.forest                 = p_lgl(default = TRUE, tags = "train")
@@ -72,8 +71,8 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
         param_set = ps,
         predict_types = c("response", "se"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
-        properties = c("weights", "importance", "oob_error"),
-        packages = "ranger",
+        properties = c("weights", "importance", "oob_error", "hotstart_backward"),
+        packages = c("mlr3learners", "ranger"),
         man = "mlr3learners::mlr_learners_regr.ranger"
       )
     },
@@ -110,7 +109,7 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
-      pv = ranger_get_mtry(pv, task)
+      pv = convert_ratio(pv, "mtry", "mtry.ratio", length(task$feature_names))
 
       if (self$predict_type == "se") {
         pv$keep.inbag = TRUE # nolint
@@ -126,12 +125,16 @@ LearnerRegrRanger = R6Class("LearnerRegrRanger",
 
     .predict = function(task) {
       pv = self$param_set$get_values(tags = "predict")
-      newdata = task$data(cols = task$feature_names)
+      newdata = ordered_features(task, self)
 
-      prediction = invoke(predict, self$model,
-        data = newdata,
-        type = self$predict_type, .args = pv)
+      prediction = invoke(predict, self$model, data = newdata, type = self$predict_type, .args = pv)
       list(response = prediction$predictions, se = prediction$se)
+    },
+
+    .hotstart = function(task) {
+      model = self$model
+      model$num.trees = self$param_set$values$num.trees
+      model
     }
   )
 )
