@@ -18,16 +18,16 @@ test_that("mtry.ratio", {
   task = mlr3::tsk("rats")
   learner = mlr3::lrn("surv.ranger", mtry.ratio = 0.5)
 
-  res = ranger_get_mtry(learner$param_set$values, task)
+  res = convert_ratio(learner$param_set$values, "mtry", "mtry.ratio", length(task$feature_names))
   expect_equal(
     res$mtry,
-    1
+    2
   )
   expect_null(res$mtry.ratio)
 
   learner$train(task)
   expect_equal(
     learner$model$mtry,
-    1
+    2
   )
 })
